#
# spec file for package python3-gnupg
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-gnupg
Version:        0.3.7
Release:        6.1
Url:            https://bitbucket.org/vinay.sajip/python-gnupg
Summary:        A wrapper for the Gnu Privacy Guard (GPG or GnuPG)
License:        BSD-3-Clause
Group:          Development/Languages/Python
Source:         https://pypi.python.org/packages/source/p/python-gnupg/python-gnupg-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python3
BuildRequires:  python3-devel
BuildRequires:  python3-distribute
BuildArch:      noarch

%description
This module allows easy access to GnuPG's key management, encryption and
signature functionality from Python programs. It is intended for use with
Python 2.4 or greater.

%prep
%setup -q -n python-gnupg-%{version}

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}

%files
%defattr(-,root,root,-)
%doc LICENSE.txt README.rst
%{python3_sitelib}/*

%changelog
* Sat Feb 14 2015 arun@gmx.de
- specfile:
  * update copyright year
  * update url
  * update source url to point to pypi
  * README->README.rst
  * LICENSE-> LICENSE.txt
- update to version 0.3.7:
  * Added an output keyword parameter to the sign and sign_file
    methods, to allow writing the signature to a file. Thanks to
    Jannis Leidel for the patch.
  * Allowed specifying True for the sign keyword parameter, which
    allows use of the default key for signing and avoids having to
    specify a key id when it's desired to use the default. Thanks to
    Fabian Beutel for the patch.
  * Used a uniform approach with subprocess on Windows and POSIX:
    shell=True is not used on either.
  * When signing/verifying, the status is updated to reflect any
    expired or revoked keys or signatures.
  * Handled 'NOTATION_NAME' and 'NOTATION_DATA' during verification.
  * Fixed #1, #16, #18, #20: Quoting approach changed, since now
    shell=False.
  * Fixed #14: Handled 'NEED_PASSPHRASE_PIN' message.
  * Fixed #8: Added a scan_keys method to allow scanning of keys
    without the need to import into a keyring. Thanks to Venzen
    Khaosan for the suggestion.
  * Fixed #5: Added '0x' prefix when searching for keys. Thanks to
    Aaron Toponce for the report.
  * Fixed #4: Handled 'PROGRESS' message during encryption. Thanks to
    Daniel Mills for the report.
  * Fixed #3: Changed default encoding to Latin-1.
  * Fixed #2: Raised ValueError if no recipients were specified for an
    asymmetric encryption request.
  * Handled 'UNEXPECTED' message during verification. Thanks to David
    Andersen for the patch.
  * Replaced old range(len(X)) idiom with enumerate().
  * Refactored ListKeys / SearchKeys classes to maximise use of common
    functions.
  * Fixed GC94: Added export-minimal and armor options when exporting
    keys. This addition was inadvertently left out of 0.3.6.
- changes from version 0.3.6:
  * Fixed GC82: Enabled fast random tests on gpg as well as gpg2.
  * Fixed GC85: Avoided deleting temporary file to preserve its
    permissions.
  * Fixed GC87: Avoided writing passphrase to log.
  * Fixed GC95: Added verify_data() method to allow verification of
    signatures in memory.
  * Fixed GC96: Regularised end-of-line characters.
  * Fixed GC98: Rectified problems with earlier fix for shell
    injection.
- changes from version 0.3.5:
  * Added improved shell quoting to guard against shell injection.
  * Fixed GC76: Added search_keys() and send_keys() methods.
  * Fixed GC77: Allowed specifying a symmetric cipher algorithm.
  * Fixed GC78: Fell back to utf-8 encoding when no other could be
    determined.
  * Fixed GC79: Default key length is now 2048 bits.
  * Fixed GC80: Removed the Name-Comment default in key generation.
- changes from version 0.3.4:
  * Fixed GC65: Fixed encoding exception when getting version.
  * Fixed GC66: Now accepts sets and frozensets where appropriate.
  * Fixed GC67: Hash algorithm now captured in sign result.
  * Fixed GC68: Added support for --secret-keyring.
  * Fixed GC70: Added support for multiple keyrings.
- changes from version 0.3.3:
  * Fixed GC57: Handled control characters in list_keys().
  * Fixed GC61: Enabled fast random for testing.
  * Fixed GC62: Handled KEYEXPIRED status.
  * Fixed GC63: Handled NO_SGNR status.
* Thu Jan 17 2013 alexandre@exatati.com.br
- Update to 0.3.2:
  - Fixed Issue #56: Disallow blank values in key generation.
  - Fixed Issue #57: Handle colons and other characters in list_keys.
  - Fixed Issue #59 and Issue #60: Handle INV_SGNR status during
    verification and removed calls requiring interactive password
    input from doctests.
* Mon Jan 14 2013 saschpe@suse.de
- Don't require "python(abi)", RPM does that automatically
* Fri Jan 11 2013 p.drouand@gmail.com
- Initial python3 support
